from sqlalchemy import *

from sickrage.core.common import SearchFormats


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tv_shows = Table('tv_shows', meta, autoload=True)
    if not hasattr(tv_shows.c, 'scene'):
        scene = Column('scene', Boolean, default=0)
        scene.create(tv_shows)

        with migrate_engine.begin() as conn:
            for row in migrate_engine.execute(tv_shows.select()):
                if row.search_format == 5:
                    conn.execute(tv_shows.update().where(tv_shows.c.indexer_id == row.indexer_id).values(scene=1, search_format=SearchFormats.STANDARD))


def downgrade(migrate_engine):
    pass



import datetime

from sqlalchemy import *


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tv_shows = Table('tv_shows', meta, autoload=True)
    if not hasattr(tv_shows.c, 'last_xem_refresh'):
        last_xem_refresh = Column('last_xem_refresh', Integer, default=datetime.datetime.now().toordinal())
        last_xem_refresh.create(tv_shows)

    xem_refresh = Table('xem_refresh', meta, autoload=True)
    if xem_refresh is not None:
        with migrate_engine.begin() as conn:
            for row in migrate_engine.execute(xem_refresh.select()):
                conn.execute(tv_shows.update().where(tv_shows.c.indexer_id == row.indexer_id).values(last_xem_refresh=row.last_refreshed))
        xem_refresh.drop()


def downgrade(migrate_engine):
    pass



# ##############################################################################
#  Author: echel0n <echel0n@sickrage.ca>
#  URL: https://sickrage.ca/
#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
#  -
#  This file is part of SiCKRAGE.
#  -
#  SiCKRAGE is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#  -
#  SiCKRAGE is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  -
#  You should have received a copy of the GNU General Public License
#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
# ##############################################################################
from abc import ABC

from tornado.web import authenticated

import sickrage
from sickrage.core.common import Quality
from sickrage.core.webserver import ConfigHandler
from sickrage.core.webserver.handlers.base import BaseHandler


class ConfigQualitySettingsHandler(BaseHandler, ABC):
    @authenticated
    async def get(self, *args, **kwargs):
        await self.run_in_executor(self.handle_get)

    def handle_get(self):
        return self.render('config/quality_settings.mako',
                           submenu=ConfigHandler.menu,
                           title=_('Config - Quality Settings'),
                           header=_('Quality Settings'),
                           topmenu='config',
                           controller='config',
                           action='quality_settings')


class SaveQualitiesHandler(BaseHandler, ABC):
    @authenticated
    async def post(self, *args, **kwargs):
        await self.run_in_executor(self.handle_post)

    def handle_post(self):
        quality_sizes = {
            Quality.UNKNOWN: int(self.get_argument(str(Quality.UNKNOWN))),
            Quality.SDTV: int(self.get_argument(str(Quality.SDTV))),
            Quality.SDDVD: int(self.get_argument(str(Quality.SDDVD))),
            Quality.HDTV: int(self.get_argument(str(Quality.HDTV))),
            Quality.RAWHDTV: int(self.get_argument(str(Quality.RAWHDTV))),
            Quality.FULLHDTV: int(self.get_argument(str(Quality.FULLHDTV))),
            Quality.HDWEBDL: int(self.get_argument(str(Quality.HDWEBDL))),
            Quality.FULLHDWEBDL: int(self.get_argument(str(Quality.FULLHDWEBDL))),
            Quality.HDBLURAY: int(self.get_argument(str(Quality.HDBLURAY))),
            Quality.FULLHDBLURAY: int(self.get_argument(str(Quality.FULLHDBLURAY))),
            Quality.UHD_4K_TV: int(self.get_argument(str(Quality.UHD_4K_TV))),
            Quality.UHD_4K_WEBDL: int(self.get_argument(str(Quality.UHD_4K_WEBDL))),
            Quality.UHD_4K_BLURAY: int(self.get_argument(str(Quality.UHD_4K_BLURAY))),
            Quality.UHD_8K_TV: int(self.get_argument(str(Quality.UHD_8K_TV))),
            Quality.UHD_8K_WEBDL: int(self.get_argument(str(Quality.UHD_8K_WEBDL))),
            Quality.UHD_8K_BLURAY: int(self.get_argument(str(Quality.UHD_8K_BLURAY))),
        }

        sickrage.app.config.quality_sizes.update(quality_sizes)

        sickrage.app.config.save()

        sickrage.app.alerts.message(_('[QUALITY SETTINGS] Configuration Encrypted and Saved to disk'))

        return self.redirect("/config/qualitySettings/")



# ##############################################################################
#  Author: echel0n <echel0n@sickrage.ca>
#  URL: https://sickrage.ca/
#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
#  -
#  This file is part of SiCKRAGE.
#  -
#  SiCKRAGE is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#  -
#  SiCKRAGE is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  -
#  You should have received a copy of the GNU General Public License
#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
# ##############################################################################
from abc import ABC

import tornado.web

import sickrage
from sickrage.core.webserver.handlers.base import BaseHandler


class NotFoundHandler(BaseHandler, ABC):
    def prepare(self):
        url = self.request.uri

        if sickrage.app.config.web_root:
            if not self.request.uri.startswith(sickrage.app.config.web_root):
                return self.redirect(url)

            url = url[len(sickrage.app.config.web_root) + 1:]

        if url[:3] != 'api':
            raise tornado.web.HTTPError(
                status_code=404,
                reason="You have reached this page by accident, please check the url."
            )

        raise tornado.web.HTTPError(
            status_code=401,
            reason="Wrong API key used."
        )



# ##############################################################################
#  Author: echel0n <echel0n@sickrage.ca>
#  URL: https://sickrage.ca/
#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
#  -
#  This file is part of SiCKRAGE.
#  -
#  SiCKRAGE is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#  -
#  SiCKRAGE is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  -
#  You should have received a copy of the GNU General Public License
#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
# ##############################################################################

from sqlalchemy import *


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    history = Table('history', meta, autoload=True)
    if not hasattr(history.c, 'release_group'):
        release_group = Column('release_group', Text, default='')
        release_group.create(history)


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    history = Table('history', meta, autoload=True)
    if hasattr(history.c, 'release_group'):
        history.c.release_group.drop()



import datetime

from sqlalchemy import *


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tv_episodes = Table('tv_episodes', meta, autoload=True)
    if not hasattr(tv_episodes.c, 'xem_season'):
        xem_season = Column('xem_season', Integer, default=-1)
        xem_season.create(tv_episodes)
    if not hasattr(tv_episodes.c, 'xem_episode'):
        xem_episode = Column('xem_episode', Integer, default=-1)
        xem_episode.create(tv_episodes)
    if not hasattr(tv_episodes.c, 'xem_absolute_number'):
        xem_absolute_number = Column('xem_absolute_number', Integer, default=-1)
        xem_absolute_number.create(tv_episodes)


def downgrade(migrate_engine):
    pass



from sqlalchemy import *


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tv_episodes = Table('tv_episodes', meta, autoload=True)
    scene_numbering = Table('scene_numbering', meta, autoload=True)

    if scene_numbering is not None:
        with migrate_engine.begin() as conn:
            for row in migrate_engine.execute(scene_numbering.select()):
                conn.execute(tv_episodes.update().where(
                    tv_episodes.c.show_id == row.indexer_id,
                    tv_episodes.c.season == row.season,
                    tv_episodes.c.episode == row.episode
                ).values(
                    scene_season=row.scene_season,
                    scene_episode=row.scene_episode
                ))

        scene_numbering.drop()


def downgrade(migrate_engine):
    pass
